generate_mapping — spacr 0.5.0 documentation

# generate_mapping

## Module Contents

generate_mapping.public_paths_labeled(root)

  Map paths for public datasets as dictionary list

generate_mapping.official_paths_labeled(root)

  Map paths for official labeled datasets as dictionary list

generate_mapping.official_paths_tuning(root)

  Map paths for official tuning datasets as dictionary list

generate_mapping.add_mapping_to_json(json_file, map_dict)

  Save mapped dictionary as a json file

generate_mapping.parser